package com.hzya.frame.nifi.service;

import cn.hutool.core.util.StrUtil;
import com.hzya.frame.nifi.client.NifiClient;
import com.hzya.frame.nifi.model.joinbindparametercontexts.BindParameterContextsJoin11;
import com.hzya.frame.nifi.model.joincontrollerenabled.EnOrDiControllerServices12;
import com.hzya.frame.nifi.model.joingetcontroller.ControllerService12;
import com.hzya.frame.nifi.model.joinparametercontexts.ParameterContextsJoin;
import com.hzya.frame.nifi.model.joinprocessgroups.ProcessGroupsJoin;
import com.hzya.frame.nifi.model.joinstartorstopprocessgroup.StartOrStopProcessGroupsInfoJoin10;
import com.hzya.frame.nifi.model.processgroupid.ProcessGroupsId;
import com.hzya.frame.nifi.model.processgrouproot.ProcessGroupsRoot;
import com.hzya.frame.nifi.model.resultparametercontexts.ParameterContextsResult;
import com.hzya.frame.nifi.model.resultprocessgroups.ProcessgroupsResult;
import com.hzya.frame.nifi.model.resultprocessgroupsinfo.ProcessGroupsInfoResult9;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * nifi api 服务类
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.nifi.service
 * @Project：fw-nifi
 * @name：NifiService
 * @Date：2025/5/14 10:02
 * @Filename：NifiService
 */
@Service
public class NifiApiService {

    private final NifiClient client;

    @Autowired
    public NifiApiService(NifiClient client) {
        this.client = client;
    }

    /**
     * 获取token
     */
    public String getAccessToken() throws Exception {
        return client.getAccessToken();
    }

    /**
     * 查询全部流程
     */
    public ProcessGroupsRoot queryFlowProcessGroupsRoot() throws Exception {
        return client.get("/flow/process-groups/root", ProcessGroupsRoot.class);
    }

    /**
     * 查询指定流程
     */
    public ProcessGroupsId queryFlowProcessGroupsRoot(String flowGroupId) throws Exception {
        return client.get(StrUtil.format("/flow/process-groups/{}", flowGroupId), ProcessGroupsId.class);
    }

    /**
     * 创建参数上下文
     */
    public ParameterContextsResult createParameterContexts(ParameterContextsJoin parameterContextsJoin) throws Exception {
        return client.post("/parameter-contexts", parameterContextsJoin, ParameterContextsResult.class);
    }

    /**
     * 更新参数上下文
     */
    public ParameterContextsResult updateParameterContexts(ParameterContextsResult parameterContextsJoin) throws Exception {
        return client.post(StrUtil.format("/parameter-contexts/{}/update-requests", parameterContextsJoin.getId()), parameterContextsJoin, ParameterContextsResult.class);
    }

    /**
     * 查询参数上下文
     */
    public ParameterContextsResult getParameterContexts(String paramContextsId) throws Exception {
        return client.get(StrUtil.format("/parameter-contexts/{}", paramContextsId), ParameterContextsResult.class);
    }

    /**
     * 删除参数上下文
     */
    public void deleteParameterContexts(String paramContextsId) throws Exception {
        client.delete(StrUtil.format("/parameter-contexts/{}", paramContextsId), ParameterContextsResult.class);
    }

    /**
     * 删除参数上下文
     */
    public ParameterContextsResult deleteParameterContexts(String id, Map<String, String> queryParams) throws Exception {
        return client.delete(StrUtil.format("/parameter-contexts/{}", id), queryParams, ParameterContextsResult.class);
    }

    /**
     * 查询流程组详情
     */
    public ProcessGroupsInfoResult9 getProcessGroups(String processGroups) throws Exception {
        return client.get(StrUtil.format("/process-groups/{}", processGroups), ProcessGroupsInfoResult9.class);
    }

    /**
     * 创建流程组
     */
    public ProcessgroupsResult createProcessGroups(String parentGroupId, ProcessGroupsJoin processGroupsJoin) throws Exception {
        return client.post(StrUtil.format("/process-groups/{}/process-groups", parentGroupId), processGroupsJoin, ProcessgroupsResult.class);
    }

    /**
     * 删除流程组
     */
    public ProcessGroupsInfoResult9 deleteProcessGroups(String parentGroupId, Map<String, String> queryParams) throws Exception {
        return client.delete(StrUtil.format("/process-groups/{}", parentGroupId), queryParams, ProcessGroupsInfoResult9.class);
    }

    /**
     * 启动或停止流程组
     */
    public ProcessGroupsInfoResult9 startOrStopProcessGroups(StartOrStopProcessGroupsInfoJoin10 startOrStopProcessGroupsInfoJoin10) throws Exception {
        return client.put(StrUtil.format("/flow/process-groups/{}", startOrStopProcessGroupsInfoJoin10.getId()), startOrStopProcessGroupsInfoJoin10, ProcessGroupsInfoResult9.class);
    }

    /**
     * 给流程组绑定参数上下文环境、或者给流程组更新上下文环境
     */
    public ProcessGroupsInfoResult9 bindParameterContexts(BindParameterContextsJoin11 bindParameterContextsJoin) throws Exception {
        String id = bindParameterContextsJoin.getComponent().getId();
        return client.put(StrUtil.format("/process-groups/{}", id), bindParameterContextsJoin, ProcessGroupsInfoResult9.class);
    }

    /**
     * 查询控制器服务详情
     */
    public ControllerService12 getControllerServices(String controllerServicesId) throws Exception {
        return client.get(StrUtil.format("/controller-services/{}", controllerServicesId), ControllerService12.class);
    }

    /**
     * 创建流程组组级别的控制器服务,控制器服务分为流程组级别和全局级别，其中流程组级别只能在流程组内的处理器共享
     *
     * @param id                  对应的流程组id
     * @param controllerService11 提交参数
     */
    public ControllerService12 createControllerServices(String id, ControllerService12 controllerService11) throws Exception {
        return client.post(StrUtil.format("/process-groups/{}/controller-services", id), controllerService11, ControllerService12.class);
    }

    /**
     * 启用或禁用控制器服务
     */
    public ControllerService12 enabledOrDisabledControllerServices(String id, EnOrDiControllerServices12 enOrDiControllerServices) throws Exception {
        return client.put(StrUtil.format("/controller-services/{}/run-status", id), enOrDiControllerServices, ControllerService12.class);
    }

    /**
     * 删除控制器服务
     */
    public ControllerService12 deleteControllerServices(String id, Map<String, String> queryParam) throws Exception {
        return client.delete(StrUtil.format("/controller-services/{}", id), queryParam, ControllerService12.class);
    }
}